# Generated by Django 3.0.5 on 2020-04-02 15:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users_extended', '0002_auto_20200402_1300'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserAditionalPermission',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
            options={
                'permissions': (('list_user', 'Can list user'), ('change_password_user', 'Can change user password'), ('detail_user', 'Can detail user'), ('make_superuser_user', 'Can make user superuser'), ('make_staff_user', 'Can make user staff'), ('make_active_user', 'Can make user active')),
                'managed': False,
            },
        ),
    ]
