# Generated by Django 3.0.5 on 2020-04-05 11:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users_extended', '0004_auto_20200404_1600'),
    ]

    operations = [
        migrations.AddField(
            model_name='extendeduser',
            name='date_of_birth',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='extendeduser',
            name='gender',
            field=models.CharField(blank=True, choices=[('M', 'Masculino'), ('F', 'Femenino')], max_length=1, null=True),
        ),
    ]
