# Generated by Django 3.0.5 on 2020-04-26 02:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users_extended', '0009_auto_20200425_1410'),
    ]

    operations = [
        migrations.AddField(
            model_name='extendeduser',
            name='registration_expiration',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='extendeduser',
            name='registration_token',
            field=models.CharField(max_length=400, null=True),
        ),
    ]
