# Generated by Django 3.0.5 on 2020-04-11 01:32

import app_configurations.models
from django.db import migrations, models
import imagekit.models.fields


class Migration(migrations.Migration):

    dependencies = [
        ('app_configurations', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='address',
            field=models.TextField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='attention_schedule',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='contact_emails',
            field=models.TextField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='facebook',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='favicon',
            field=imagekit.models.fields.ProcessedImageField(blank=True, null=True, upload_to=app_configurations.models.GeneralInfoConfiguration.imagen_favicon_upload_to),
        ),
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='instagram',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='linkedin',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='twitter',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='whatsaap',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='generalinfoconfiguration',
            name='youtube',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
    ]
