# Generated by Django 3.0.5 on 2020-05-03 03:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('countries', '0003_auto_20200503_0312'),
    ]

    operations = [
        migrations.AlterField(
            model_name='country',
            name='currency',
            field=models.CharField(max_length=3, null=True),
        ),
        migrations.AlterField(
            model_name='country',
            name='iso2',
            field=models.CharField(max_length=2, null=True),
        ),
        migrations.AlterField(
            model_name='country',
            name='iso3',
            field=models.CharField(max_length=3, null=True),
        ),
        migrations.AlterField(
            model_name='country',
            name='phone_code',
            field=models.PositiveIntegerField(null=True),
        ),
        migrations.AlterField(
            model_name='state',
            name='state_code',
            field=models.CharField(max_length=3, null=True),
        ),
    ]
