# Generated by Django 3.0.5 on 2020-05-03 03:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('countries', '0002_auto_20200503_0312'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='city',
            options={'permissions': (('list_city', 'Can list cities'),)},
        ),
        migrations.AlterModelOptions(
            name='state',
            options={'permissions': (('list_state', 'Can list states'),)},
        ),
    ]
